@@ -27,9 +27,9 @@ OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 try:
     from functools import update_wrapper
 except ImportError: # pragma: no cover
-    from .util import update_wrapper
+    from cli.util import update_wrapper
 
-from .util import fmtsec
+from cli.util import Stats, fmtsec
 
 __all__ = ["Profiler"]
 
@@ -112,7 +112,6 @@ class Profiler(object):
         to :attr:`stdout`. The profiling statistics are saved to the
         :attr:`stats` attribute after the run.
         """
-        from pstats import Stats
 
         try:
             from cProfile import Profile
@@ -121,7 +120,7 @@ class Profiler(object):
         profiler = Profile()
 
         def wrapper(*args, **kwargs):
-            self.stdout.write("===> Profiling %s:\n" % func.__name__)
+            self.stdout.write(u"===> Profiling %s:\n" % func.__name__)
             profiler.runcall(func, *args, **kwargs)
             self.stats = Stats(profiler, stream=self.stdout)
             self.stats.strip_dirs().sort_stats(-1).print_stats()
@@ -160,9 +159,9 @@ class Profiler(object):
             return [timeit(func, *args, **kwargs) for i in range(self.repeat)]
 
         def wrapper(*args, **kwargs):
-            self.stdout.write("===> Profiling %s: " % func.__name__)
+            self.stdout.write(u"===> Profiling %s: " % func.__name__)
             self.result = min(repeat(func, *args, **kwargs))
-            self.stdout.write("%d loops, best of %d: %s per loop\n" % (
+            self.stdout.write(u"%d loops, best of %d: %s per loop\n" % (
                 self.count, self.repeat, fmtsec(self.result/self.count)))
 
         return self.wrap(wrapper, func)
